///<reference path="fourslash.ts" />

////var a = { f: /**/a

goTo.marker();
verify.quickInfoIs("var a: any", null);
